﻿using System.Collections.ObjectModel;
using System.Linq;
using System.Windows;
using System.Windows.Input;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.CommandWpf;
using Infragistics.Controls.Schedules;
using Poc.Schedule.Model;

namespace Poc.Schedule.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// See http://www.mvvmlight.net
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        private readonly IDataService _dataService;
        private OutlookCalendarViewMode _outlookCalendarViewMode;

        /// <summary>
        /// Initializes a new instance of the MainViewModel class.
        /// </summary>
        public MainViewModel(IDataService dataService)
        {
            _dataService = dataService;

            Resources = new ObservableCollection<Resource>();
            ResourceCalendars = new ObservableCollection<ResourceCalendar>();
            Appointments = new ObservableCollection<Appointment>();

            var appointments = _dataService.GetAppointments();
            appointments.ToList().ForEach(a => Appointments.Add(a));

            Resources.Add(new Resource { Id = "Resource", Name = "Lima" });
            ResourceCalendars.Add(new ResourceCalendar { Id = "Cal", OwningResourceId = "Resource" });

            DayViewCommand = new RelayCommand(DayViewExecute);
            WeekViewCommand = new RelayCommand(WeekViewExecute);
            MonthViewCommand = new RelayCommand(MonthViewExecute);
            OpenAppointmentCommand = new RelayCommand<ActivityDialogDisplayingEventArgs>(OpenAppointmentExecute);

            OutlookCalendarViewMode = OutlookCalendarViewMode.MonthView;
        }

        public ObservableCollection<Resource> Resources { get; set; }
        public ObservableCollection<ResourceCalendar> ResourceCalendars { get; set; }
        public ObservableCollection<Appointment> Appointments { get; set; }

        public OutlookCalendarViewMode OutlookCalendarViewMode
        {
            get { return _outlookCalendarViewMode; }
            set { Set(ref _outlookCalendarViewMode, value); }
        }

        public ICommand DayViewCommand { get; }
        public ICommand WeekViewCommand { get; }
        public ICommand MonthViewCommand { get; }
        public ICommand OpenAppointmentCommand { get; }

        private void MonthViewExecute()
        {
            OutlookCalendarViewMode = OutlookCalendarViewMode.MonthView;
        }

        private void WeekViewExecute()
        {
            OutlookCalendarViewMode = OutlookCalendarViewMode.DayViewWeek;
        }

        private void DayViewExecute()
        {
            OutlookCalendarViewMode = OutlookCalendarViewMode.DayViewDay;
        }

        private void OpenAppointmentExecute(ActivityDialogDisplayingEventArgs e)
        {
            MessageBox.Show($"Opening Appointment: {e?.Activity?.Subject} ...");
        }
    }
}